import React from 'react';
import { compose, withProps } from "recompose";
import { withScriptjs, withGoogleMap, StreetViewPanorama, GoogleMap, Marker } from "react-google-maps";
import { GOOGLE_API_KEY } from "../config";
import RoundTimer from "./round-timer.component";

// TODO want a button for moving the pano back to start somehow

const PositionedStreetView = compose(
  withProps({
    googleMapURL: `https://maps.googleapis.com/maps/api/js?key=${GOOGLE_API_KEY}&v=3.exp&libraries=geometry,drawing,places`,
    loadingElement: <div style={{ height: `100%` }} />,
    containerElement: <div style={{ height: `70vh` }} />,
    mapElement: <div style={{ height: `100%` }} />,
  }),
  withScriptjs,
  withGoogleMap
)(({ point }) =>
  <StreetViewPanorama
    defaultPosition={point}
    options={{
      addressControl: false,
      showRoadLabels: false,
      clickToGo: true,
    }}
    visible
  />
);

const SelectionMap = compose(
  withProps({
    googleMapURL: `https://maps.googleapis.com/maps/api/js?key=${GOOGLE_API_KEY}&v=3.exp&libraries=geometry,drawing,places`,
    loadingElement: <div style={{ height: `100%` }} />,
    containerElement: <div style={{ height: `250px` }} />,
    mapElement: <div style={{ height: `100%` }} />,
  }),
  withScriptjs,
  withGoogleMap
)(({onClick, markerPosition}) =>
  <GoogleMap
    defaultZoom={1}
    defaultCenter={{ lat: 25, lng: -25}}
    clickableIcons={false}
    options={{
      disableDefaultUI: true,
      fullscreenControl: true,
    }}
    onClick={onClick}>
      {markerPosition ? <Marker
        clickable={false}
        draggable={false}
        position={markerPosition}
      /> : null}
  </GoogleMap>
);

const GamePanel = ({
  onSelectPoint,
  onSubmitGuess,
  streetViewPoint,
  selectedPoint,
  roundSeconds,
  onTimeout,
}) => (
  <div style={{
    display: "flex",
    justifyContent: "space-between",
    alignItems: "center"
  }}>
    <div style={{ flexGrow: 3 }}>
      <PositionedStreetView
        point={streetViewPoint}
      />
    </div>
    <div style={{
      flexGrow: 1,
      display: "flex",
      flexDirection: "column",
      justifyContent:"space-around",
    }}>
      <RoundTimer seconds={roundSeconds} onTimeout={onTimeout} />
      <SelectionMap
        onClick={({ latLng }) => onSelectPoint({ lat: latLng.lat(), lng: latLng.lng() })}
        markerPosition={selectedPoint}
      />
      <button
        onClick={onSubmitGuess}
        disabled={selectedPoint === null}
      >
        Submit Guess
      </button>
    </div>
  </div>
);

export default GamePanel;
